/* --COPYRIGHT--,BSD
 * Copyright (c) 2014, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/

//*****************************************************************************
// Thermostat_UI_LEDs.h
//
//!  Defines & macros specific to LED control for thermostat application
//
//!  \author: a0273983, Created on: Aug 3, 2015
//!  \author: a0224638, Revised on: Sept 8, 2015
//
//*****************************************************************************

//*****************************************************************************
//! \addtogroup Thermostat_UI_LEDs
//! @{
//*****************************************************************************

#ifndef TIDM_CAPTIVATE_THERMOSTAT_UI_LEDS_H_
#define TIDM_CAPTIVATE_THERMOSTAT_UI_LEDS_H_

#include <msp430.h>
#include "Thermostat_UI_Demo.h"

//*****************************************************************************
// UP LED defines
//*****************************************************************************

//! \brief Defines the PxOUT register associated with the UP LED
//!
#define UP_LED_POUT        (P2OUT)

//! \brief Defines the PxDIR register associated with the UP LED
//!
#define UP_LED_PDIR        (P2DIR)

//! \brief Defines the pin that controls the UP LED
//!
#define UP_LED_PIN         (BIT0)

//! \brief Macro for turning the UP LED on
//!
#define UP_LED_ON          (UP_LED_POUT &= ~UP_LED_PIN)

//! \brief Macro for turning the UP LED off
//!
#define UP_LED_OFF         (UP_LED_POUT |= UP_LED_PIN)

//! \brief Macro for toggling the UP LED state
//!
#define UP_LED_TOGGLE      (UP_LED_POUT ^= UP_LED_PIN)

//*****************************************************************************
// DOWN LED defines
//*****************************************************************************

//! \brief Defines the PxOUT register associated with the DOWN LED
//!
#define DOWN_LED_POUT        (P2OUT)

//! \brief Defines the PxDIR register associated with the DOWN LED
//!
#define DOWN_LED_PDIR        (P2DIR)

//! \brief Defines the pin that controls the DOWN LED
//!
#define DOWN_LED_PIN         (BIT1)

//! \brief Macro for turning the DOWN LED on
//!
#define DOWN_LED_ON          (DOWN_LED_POUT &= ~DOWN_LED_PIN)

//! \brief Macro for turning the DOWN LED off
//!
#define DOWN_LED_OFF         (DOWN_LED_POUT |= DOWN_LED_PIN)

//! \brief Macro for toggling the DOWN LED state
//!
#define DOWN_LED_TOGGLE      (DOWN_LED_POUT ^= DOWN_LED_PIN)

//*****************************************************************************
// SET LED defines
//*****************************************************************************

//! \brief Defines the PxOUT register associated with the SET LED
//!
#define SET_LED_POUT        (P2OUT)

//! \brief Defines the PxDIR register associated with the SET LED
//!
#define SET_LED_PDIR        (P2DIR)

//! \brief Defines the pin that controls the SET LED
//!
#define SET_LED_PIN         (BIT6)

//! \brief Macro for turning the SET LED on
//!
#define SET_LED_ON          (SET_LED_POUT &= ~SET_LED_PIN)

//! \brief Macro for turning the SET LED off
//!
#define SET_LED_OFF         (SET_LED_POUT |= SET_LED_PIN)

//! \brief Macro for toggling the SET LED state
//!
#define SET_LED_TOGGLE      (SET_LED_POUT ^= SET_LED_PIN)

//*****************************************************************************
// HOLD LED defines
//*****************************************************************************

//! \brief Defines the PxOUT register associated with the HOLD LED
//!
#define HOLD_LED_POUT        (P1OUT)

//! \brief Defines the PxDIR register associated with the HOLD LED
//!
#define HOLD_LED_PDIR        (P1DIR)

//! \brief Defines the pin that controls the HOLD LED
//!
#define HOLD_LED_PIN         (BIT0)

//! \brief Macro for turning the HOLD LED on
//!
#define HOLD_LED_ON          (HOLD_LED_POUT &= ~HOLD_LED_PIN)

//! \brief Macro for turning the HOLD LED off
//!
#define HOLD_LED_OFF         (HOLD_LED_POUT |= HOLD_LED_PIN)

//! \brief Macro for toggling the HOLD LED state
//!
#define HOLD_LED_TOGGLE      (HOLD_LED_POUT ^= HOLD_LED_PIN)

//*****************************************************************************
// FAN AUTO LED defines
//*****************************************************************************

//! \brief Defines the PxOUT register associated with the FAN Auto LED
//!
#define FANAUTO_LED_POUT        (P2OUT)

//! \brief Defines the PxDIR register associated with the FAN Auto LED
//!
#define FANAUTO_LED_PDIR        (P2DIR)

//! \brief Defines the pin that controls the FAN Auto LED
//!
#define FANAUTO_LED_PIN         (BIT5)

//! \brief Macro for turning the FAN Auto LED on
//!
#define FANAUTO_LED_ON          (FANAUTO_LED_POUT &= ~FANAUTO_LED_PIN)

//! \brief Macro for turning the FAN Auto LED off
//!
#define FANAUTO_LED_OFF         (FANAUTO_LED_POUT |= FANAUTO_LED_PIN)

//! \brief Macro for toggling the FAN Auto LED state
//!
#define FANAUTO_LED_TOGGLE      (FANAUTO_LED_POUT ^= FANAUTO_LED_PIN)

//*****************************************************************************
// FAN ON LED defines
//*****************************************************************************

//! \brief Defines the PxOUT register associated with the FAN On LED
//!
#define FANON_LED_POUT        (P1OUT)

//! \brief Defines the PxDIR register associated with the FAN On LED
//!
#define FANON_LED_PDIR        (P1DIR)

//! \brief Defines the pin that controls the FAN On LED
//!
#define FANON_LED_PIN         (BIT7)

//! \brief Macro for turning the FAN On LED on
//!
#define FANON_LED_ON          (FANON_LED_POUT &= ~FANON_LED_PIN)

//! \brief Macro for turning the FAN On LED off
//!
#define FANON_LED_OFF         (FANON_LED_POUT |= FANON_LED_PIN)

//! \brief Macro for toggling the FAN On LED state
//!
#define FANON_LED_TOGGLE      (FANON_LED_POUT ^= FANON_LED_PIN)

//*****************************************************************************
// HEAT LED defines
//*****************************************************************************

//! \brief Defines the PxOUT register associated with the HEAT LED
//!
#define HEAT_LED_POUT        (P2OUT)

//! \brief Defines the PxDIR register associated with the HEAT LED
//!
#define HEAT_LED_PDIR        (P2DIR)

//! \brief Defines the pint that controls the HEAT LED
//!
#define HEAT_LED_PIN         (BIT4)

//! \brief Macro for turning the HEAT LED on
//!
#define HEAT_LED_ON          (HEAT_LED_POUT &= ~HEAT_LED_PIN)

//! \brief Macro for turning the HEAT LED off
//!
#define HEAT_LED_OFF         (HEAT_LED_POUT |= HEAT_LED_PIN)

//! \brief Macro for toggling the HEAT LED state
//!
#define HEAT_LED_TOGGLE      (HEAT_LED_POUT ^= HEAT_LED_PIN)

//*****************************************************************************
// COOL LED defines
//*****************************************************************************

//! \brief Defines the PxOUT register associated with the COOL LED
//!
#define COOL_LED_POUT        (P1OUT)

//! \brief Defines the PxDIR register associated with the COOL LED
//!
#define COOL_LED_PDIR        (P1DIR)

//! \brief Defines the pin that controls the COOL LED
//!
#define COOL_LED_PIN         (BIT6)

//! \brief Macro for turning the COOL LED on
//!
#define COOL_LED_ON          (COOL_LED_POUT &= ~COOL_LED_PIN)

//! \brief Macro for turning the COOL LED off
//!
#define COOL_LED_OFF         (COOL_LED_POUT |= COOL_LED_PIN)

//! \brief Macro for toggling the COOL LED state
//!
#define COOL_LED_TOGGLE      (COOL_LED_POUT ^= COOL_LED_PIN)

//*****************************************************************************
// Function Prototypes
//*****************************************************************************

//! \brief        Updates the state of the button LEDs to match the thermostat state
//! \param fanState    State of the fan
//!                    VALID VALUES: FanOn, FanOff, FanAuto
//! \param unitState   State of the heating/cooling unit
//!                    VALID VALUES: UnitsOff, Heat, Cool
//! \param hold        The hold state
extern void LEDs_updateStatus(FanState fanState, UnitState unitState, bool hold);

//*****************************************************************************
// Close the Doxygen group.
//! @}
//*****************************************************************************

#endif /* TIDM_CAPTIVATE_THERMOSTAT_UI_LEDS_H_ */
