/* --COPYRIGHT--,BSD
 * Copyright (c) 2014, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/

#include "stdbool.h"
#include "Thermostat_UI_LEDs.h"

void LEDs_updateStatus(FanState fanState, UnitState unitState, bool hold)
{
	// Update FAN Auto/FAN On LEDs to match the fan state
	switch (fanState)
	{
		case FanState_Off:
			// Turn off both FAN button LEDs
			FANAUTO_LED_OFF;
			FANON_LED_OFF;
			break;

		case FanState_Auto:
			// Turn on FAN Auto LED and turn off FAN On LED
			FANAUTO_LED_ON;
			FANON_LED_OFF;
			break;

		case FanState_On:
			// Turn off FAN Auto LED and turn on FAN On LED
			FANAUTO_LED_OFF;
			FANON_LED_ON;
			break;
	}

	// Update Heat/Cool LEDs to match the heating/cooling unit state
	switch (unitState)
	{
		case UnitState_Off:
			// Turn off heat/cool LEDs
			HEAT_LED_OFF;
			COOL_LED_OFF;
			break;

		case UnitState_Heat:
			// Turn on heat LED and turn off cool LED
			HEAT_LED_ON;
			COOL_LED_OFF;
			break;

		case UnitState_Cool:
			// Turn off heat LED and turn on cool LED
			HEAT_LED_OFF;
			COOL_LED_ON;
			break;
	}

	// Update HOLD LED to match the given hold state
	if (hold == true)
	{
		HOLD_LED_ON;
	}
	else
	{
		HOLD_LED_OFF;
	}
}
