//*****************************************************************************
// I2CMaster.h
//
// \version __I2CMASTER_LIB_BUILD_VERSION__
// Released on __I2CMASTER_LIB_BUILD_DATE__
//
//*****************************************************************************

#ifndef I2CMASTER_H_
#define I2CMASTER_H_

#include <driverlib.h>
#include "I2CMaster_Definitions.h"

#if (I2CMASTER__ENABLE==true)

enum
{
	eI2CMaster_noError = 0,
	eI2CMaster_unavailableError,
	eI2CMaster_slaveNackError,
	eI2CMaster_busTimeoutError
};
typedef uint8_t tI2CMasterError;

//*****************************************************************************
//
//! \brief Open the I2C master driver for operation.
//
//! \param none
//
//! \return none
//
//*****************************************************************************
void I2CMaster_open(void);

//*****************************************************************************
//
//! \brief Close the I2C master driver.
//
//! \param none
//
//! \return none
//
//*****************************************************************************
void I2CMaster_close(void);

//*****************************************************************************
//
//! \brief Write a buffer to an I2C slave
//
//! \param ui8Addr is the address of the slave
//! \param pData is a pointer to the data to write
//! \param ui8Cnt is the length of pData in bytes
//
//! \return true if the slave nack'ed, else false.
//
//*****************************************************************************
tI2CMasterError I2CMaster_writeBuffer(uint8_t ui8Addr, uint8_t *pData,
		uint8_t ui8Cnt);

//*****************************************************************************
//
//! \brief Read to a buffer from an I2C slave
//
//! \param ui8Addr is the address of the slave
//! \param ui8Reg is the sub-register on the slave device to read from
//! \param ui8Cnt specifies the number of bytes to read from the slave.
//
//! \return true if the slave nack'ed, else false.
//
//*****************************************************************************
tI2CMasterError I2CMaster_readBuffer(uint8_t ui8Addr, uint8_t *pData,
		uint8_t ui8Cnt);

//*****************************************************************************
//
//! \brief Write to an I2C slave at the 8-bit slave sub-register indicated.
//
//! \param ui8Addr is the address of the slave
//! \param ui8Reg is the sub-register on the slave device to write to
//! \param pData is a pointer to the data to write
//! \param ui8Cnt is the length of pData in bytes
//
//! \return true if the slave nack'ed, else false.
//
//*****************************************************************************
tI2CMasterError I2CMaster_writeReg8(uint8_t ui8Addr, uint8_t ui8Reg,
		uint8_t *pData, uint8_t ui8Cnt);

//*****************************************************************************
//
//! \brief Read from an I2C slave at the 8-bit slave sub-register indicated.
//
//! \param ui8Addr is the address of the slave
//! \param ui8Reg is the sub-register on the slave device to read from
//! \param pData is a pointer to a memory location to store the read data
//! \param ui8Cnt specifies the number of bytes to read from the slave.
//
//! \return true if the slave nack'ed, else false.
//
//*****************************************************************************
tI2CMasterError I2CMaster_readReg8(uint8_t ui8Addr, uint8_t ui8Reg, uint8_t *pData,
		uint8_t ui8Cnt);

#endif /* I2CMASTER__ENABLE==true */

#endif /* I2CMASTER_H_ */
