//*****************************************************************************
//! msp_ts430fr4_lcd.h
//
//! \brief LCD defines, typedefs, and function declarations
//
//! \author Texas Instruments
//! \author A0224638
//
//! \version Release 1
//
//*****************************************************************************

#ifndef MSP_TS430FR4_LCD_H_
#define MSP_TS430FR4_LCD_H_

//*****************************************************************************
// Defines
//*****************************************************************************
#define a       0x10                            //  AAAA
#define b       0x20                            // F    B
#define c       0x40                            // F    B
#define DOTSEG  0x80                            //  GGGG
#define f  		0x01                            // E    C
#define g       0x02                            // E    C
#define e       0x04                            //  DDDD
#define d       0x08

#define BR 10
#define DT BR+1
#define SP DT+1

#define LCD_Display_ON()	(LCDCTL0 |= LCDON)
#define	LCD_Display_OFF()	(LCDCTL0 &= ~LCDON)

#define DegF		0x01
#define DegC		0x02

#define Bat_0p		0x08
#define	Bat_25p 	Bat_0p+0x10
#define	Bat_50p 	Bat_25p+0x20
#define	Bat_75p 	Bat_50p+0x40
#define	Bat_100p 	Bat_75p+0x80

#define Fan_L0		0x40
#define Fan_L1		(Fan_L0 + 0x08)
#define Fan_L2		(Fan_L1 + 0x04)
#define Fan_L3		(Fan_L2 + 0x02)
#define Fan_L4		(Fan_L3 + 0x01)
#define Fan_Auto	(Fan_L4 + 0x10)

#define TSM_Heat	0x01
#define	TSM_Cool	0x02
#define TSM_Humi	0x04
#define TSM_Fan		0x08

#define SettingMode_Mode	0x10
#define SettingMode_Fan		0x20
#define SettingMode_Temp	0x40
#define SettingMode_Time	0x80
#define SettingMode_1224	0x01
#define SettingMode_Timer	0x02
#define SettingMode_CF		0x04
#define SettingMode_Swing	0x08
#define SettingMode_All	 	0xFF

#define	Sunday		0x01
#define	Monday		0x02
#define	Tuesday		0x04
#define	Wednesday	0x08
#define	Thursday	0x10
#define	Friday		0x20
#define	Saturday	0x40

#define TI_Logo		0x04
#define LCD_Display_LOGO()	(LCDM10 |= TI_Logo)

//*****************************************************************************
// Typedefs
//*****************************************************************************
typedef enum
{
	e12hour = 0x00,
	e24hour = 0x01
}tTimeformat;

typedef enum
{
	eDegC = 0x00,
	eDegF = 0x01
}tTempformat;

typedef enum
{
	e100p,
	e75p,
	e50p,
	e25p,
	e0p
}tBatteryvol;

typedef enum
{
	eL0 = 0x00,
	eL1 = 0x01,
	eL2 = 0x02,
	eL3 = 0x03,
	eL4 = 0x04,
	eAuto = 0x05
}tFanLevel;

typedef enum
{
	eHeat = 0x00,
	eCool = 0x01,
	eHumi = 0x02,
	eFann = 0x03,
}tTSMode;

typedef enum
{
	eAll = 0x00,
	eMode = 0x01,
	eFan = 0x02,
	eTemp = 0x03,
	eTime = 0x04,
	e1224 = 0x05,
	eTimer = 0x06,
	eCF = 0x07,
	eSwing = 0x08,
}tSettingMode;

typedef enum
{
	eSwingdisable = 0x00,
	eSwingenable = 0x01
}tSwingStatus;

//*****************************************************************************
// Function Prototypes
//*****************************************************************************
extern void LCD_displayTest();
extern void LCD_displayError(uint8_t Error_ID);

#endif /* MSP_TS430FR4_LCD_H_ */
